@@ -397,12 +397,8 @@ void Crop::update (int todo)
             MyTime t1aue, t2aue;
             t1aue.set();
 
-            int crW, crH;
-
-            if(settings->leveldnv == 0) {
-                crW = 100;
-                crH = 100;
-            }
+            int crW = 100; // settings->leveldnv == 0
+            int crH = 100; // settings->leveldnv == 0
 
             if(settings->leveldnv == 1) {
                 crW = 250;
@@ -702,7 +698,9 @@ void Crop::update (int todo)
         if (needstransform)
             parent->ipf.transform (baseCrop, transCrop, cropx / skip, cropy / skip, trafx / skip, trafy / skip, skips(parent->fw, skip), skips(parent->fh, skip), parent->getFullWidth(), parent->getFullHeight(),
                                    parent->imgsrc->getMetaData()->getFocalLen(), parent->imgsrc->getMetaData()->getFocalLen35mm(),
-                                   parent->imgsrc->getMetaData()->getFocusDist(), parent->imgsrc->getRotateDegree(), false);
+                                   parent->imgsrc->getMetaData()->getFocusDist(),
+                                   parent->imgsrc->getMetaData()->getFNumber(),
+                                   parent->imgsrc->getRotateDegree(), false);
         else
             baseCrop->copyData(transCrop);
 
@@ -811,7 +809,7 @@ void Crop::update (int todo)
         parent->ipf.vibrance (labnCrop);
 
         if((params.colorappearance.enabled && !params.colorappearance.tonecie) ||  (!params.colorappearance.enabled)) {
-            parent->ipf.EPDToneMap(labnCrop, 5, 1);
+            parent->ipf.EPDToneMap(labnCrop, 5, skip);
         }
 
         //parent->ipf.EPDToneMap(labnCrop, 5, 1);    //Go with much fewer than normal iterates for fast redisplay.
@@ -960,12 +958,12 @@ void Crop::update (int todo)
             if(settings->ciecamfloat) {
                 float d; // not used after this block
                 parent->ipf.ciecam_02float (cieCrop, float(adap), begh, endh, 1, 2, labnCrop, &params, parent->customColCurve1, parent->customColCurve2, parent->customColCurve3,
-                                            dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1, execsharp, d, skip, 1);
+                                            dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, skip, execsharp, d, 1);
             } else {
                 double dd; // not used after this block
 
                 parent->ipf.ciecam_02 (cieCrop, adap, begh, endh, 1, 2, labnCrop, &params, parent->customColCurve1, parent->customColCurve2, parent->customColCurve3,
-                                       dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, 1, execsharp, dd, skip, 1);
+                                       dummy, dummy, parent->CAMBrightCurveJ, parent->CAMBrightCurveQ, parent->CAMMean, 5, skip, execsharp, dd, 1);
             }
         } else {
             // CIECAM is disbaled, we free up its image buffer to save some space
@@ -1143,7 +1141,7 @@ bool Crop::setCropSizes (int rcx, int rcy, int rcw, int rch, int skip, bool inte
     ProcParams& params = parent->params;
 
     parent->ipf.transCoord (parent->fw, parent->fh, bx1, by1, bw, bh, orx, ory, orw, orh);
-    
+
     if (check_need_larger_crop_for_lcp_distortion(parent->fw, parent->fh, orx, ory, orw, orh, parent->params)) {
         // TODO - this is an estimate of the max distortion relative to the image size. ATM it is hardcoded to be 15%, which seems enough. If not, need to revise
         int dW = int(double(parent->fw) * 0.15 / (2 * skip));
@@ -1173,7 +1171,7 @@ bool Crop::setCropSizes (int rcx, int rcy, int rcw, int rch, int skip, bool inte
         orw = min(x2 - x1, parent->fw - orx);
         orh = min(y2 - y1, parent->fh - ory);
     }
-    
+
 
     PreviewProps cp (orx, ory, orw, orh, skip);
     int orW, orH;
