@@ -69,6 +69,7 @@ protected:
     ColorTemp autoWB;
 
     double lastAwbEqual;
+    double lastAwbTempBias;
 
     ImProcFunctions ipf;
 
@@ -156,6 +157,10 @@ protected:
     AutoExpListener* aeListener;
     AutoCamListener* acListener;
     AutoBWListener* abwListener;
+    AutoWBListener* awbListener;
+    FrameCountListener *frameCountListener;
+    ImageTypeListener *imageTypeListener;
+
     AutoColorTonListener* actListener;
     AutoChromaListener* adnListener;
     WaveletListener* awavListener;
@@ -256,7 +261,7 @@ public:
 
     DetailedCrop* createCrop  (::EditDataProvider *editDataProvider, bool isDetailWindow);
 
-    bool getAutoWB   (double& temp, double& green, double equal);
+    bool getAutoWB   (double& temp, double& green, double equal, double tempBias);
     void getCamWB    (double& temp, double& green);
     void getSpotWB   (int x, int y, int rectSize, double& temp, double& green);
     void getAutoCrop (double ratio, int &x, int &y, int &w, int &h);
@@ -311,6 +316,10 @@ public:
     {
         abwListener = abw;
     }
+    void setAutoWBListener   (AutoWBListener* awb)
+    {
+        awbListener = awb;
+    }
     void setAutoColorTonListener   (AutoColorTonListener* bwct)
     {
         actListener = bwct;
@@ -328,6 +337,16 @@ public:
         awavListener = awa;
     }
 
+    void setFrameCountListener  (FrameCountListener* fcl)
+    {
+        frameCountListener = fcl;
+    }
+
+    void setImageTypeListener  (ImageTypeListener* itl)
+    {
+        imageTypeListener = itl;
+    }
+
     void saveInputICCReference (const Glib::ustring& fname, bool apply_wb);
 
     InitialImage*  getInitialImage ()
