@@ -307,7 +307,7 @@ bool ImProcFunctions::transCoord (int W, int H, int x, int y, int w, int h, int&
 }
 
 void ImProcFunctions::transform (Imagefloat* original, Imagefloat* transformed, int cx, int cy, int sx, int sy, int oW, int oH, int fW, int fH,
-                                 double focalLen, double focalLen35mm, float focusDist, int rawRotationDeg, bool fullImage)
+                                 double focalLen, double focalLen35mm, float focusDist, double fNumber, int rawRotationDeg, bool fullImage)
 {
 
     LCPMapper *pLCPMap = nullptr;
@@ -317,7 +317,7 @@ void ImProcFunctions::transform (Imagefloat* original, Imagefloat* transformed,
 
         if (pLCPProf) {
             pLCPMap = new LCPMapper (pLCPProf, focalLen, focalLen35mm,
-                                     focusDist, 0, false,
+                                     focusDist, fNumber, false,
                                      params->lensProf.useDist,
                                      oW, oH, params->coarse, rawRotationDeg);
         }
@@ -690,7 +690,7 @@ void ImProcFunctions::transformLuminanceOnly (Imagefloat* original, Imagefloat*
     #pragma omp parallel for schedule(dynamic,16) if (multiThread)
 
     for (int y = 0; y < transformed->getHeight(); y++) {
-        double vig_y_d = (double) (y + cy) - vig_h2 ;
+        double vig_y_d = applyVignetting ? (double) (y + cy) - vig_h2 : 0.0;
 
         for (int x = 0; x < transformed->getWidth(); x++) {
             double factor = 1.0;
