@@ -172,7 +172,7 @@ void LCPPersModel::print() const
 
 // if !vignette then geometric and CA
 LCPMapper::LCPMapper(LCPProfile* pProf, float focalLength, float focalLength35mm, float focusDist, float aperture, bool vignette, bool useCADistP,
-                     int fullWidth, int fullHeight, const CoarseTransformParams& coarse, int rawRotationDeg)
+                     int fullWidth, int fullHeight, const CoarseTransformParams& coarse, int rawRotationDeg) :useCADist(false), swapXY(false), isFisheye(false), enableCA(false)
 {
     if (pProf == nullptr) {
         return;
@@ -361,6 +361,11 @@ SSEFUNCTION void LCPMapper::processVignetteLine3Channels(int width, int y, float
 
 LCPProfile::LCPProfile(const Glib::ustring &fname)
 {
+    for (int i = 0; i < MaxPersModelCount; i++) {
+        aPersModel[i] = nullptr;
+    }
+    pCurPersModel = nullptr;
+
     const int BufferSize = 8192;
     char buf[BufferSize];
 
@@ -378,27 +383,25 @@ LCPProfile::LCPProfile(const Glib::ustring &fname)
     isFisheye = inCamProfiles = firstLIDone = inPerspect = inAlternateLensID = inAlternateLensNames = false;
     sensorFormatFactor = 1;
 
-    for (int i = 0; i < MaxPersModelCount; i++) {
-        aPersModel[i] = nullptr;
-    }
-
     persModelCount = 0;
     *inInvalidTag = 0;
 
     FILE *pFile = g_fopen(fname.c_str (), "rb");
 
-    bool done;
+    if(pFile) {
+        bool done;
 
-    do {
-        int bytesRead = (int)fread(buf, 1, BufferSize, pFile);
-        done = feof(pFile);
+        do {
+            int bytesRead = (int)fread(buf, 1, BufferSize, pFile);
+            done = feof(pFile);
 
-        if (XML_Parse(parser, buf, bytesRead, done) == XML_STATUS_ERROR) {
-            throw "Invalid XML in LCP file";
-        }
-    } while (!done);
+            if (XML_Parse(parser, buf, bytesRead, done) == XML_STATUS_ERROR) {
+                throw "Invalid XML in LCP file";
+            }
+        } while (!done);
 
-    fclose(pFile);
+        fclose(pFile);
+    }
 
     XML_ParserFree(parser);
 
@@ -407,9 +410,22 @@ LCPProfile::LCPProfile(const Glib::ustring &fname)
     }
     // Two phase filter: first filter out the very rough ones, that distord the average a lot
     // force it, even if there are few frames (community profiles)
-    filterBadFrames(2.0, 0);
+//    filterBadFrames(2.0, 0);
     // from the non-distorded, filter again on new average basis, but only if there are enough frames left
-    filterBadFrames(1.5, 100);
+//    filterBadFrames(1.5, 100);
+}
+
+
+LCPProfile::~LCPProfile()
+{
+    if (pCurPersModel) {
+        delete pCurPersModel;
+    }
+    for (int i = 0; i < MaxPersModelCount; i++) {
+        if (aPersModel[i]) {
+            delete aPersModel[i];
+        }
+    }
 }
 
 // from all frames not marked as bad already, take average and filter out frames with higher deviation than this if there are enough values
@@ -431,7 +447,7 @@ int LCPProfile::filterBadFrames(double maxAvgDevFac, int minFramesLeft)
         }
 
         if (aPersModel[pm]->hasModeData(2)) {
-            errChrom += std::max(std::max(aPersModel[pm]->chromRG.mean_error, aPersModel[pm]->chromG.mean_error), aPersModel[pm]->chromBG.mean_error);
+            errChrom += rtengine::max(aPersModel[pm]->chromRG.mean_error, aPersModel[pm]->chromG.mean_error, aPersModel[pm]->chromBG.mean_error);
             chromCount++;
         }
     }
@@ -522,55 +538,66 @@ void LCPProfile::calcParams(int mode, float focalLength, float focusDist, float
             float focDist = aPersModel[pm]->focDist;
             float focDistLog = log(focDist) + euler;
             double meanErr;
-
             if (aPersModel[pm]->hasModeData(mode)) {
-                if (mode == 0) {
+                double lowMeanErr, highMeanErr;
+                switch (mode) {
+                case 0:
                     meanErr = aPersModel[pm]->vignette.mean_error;
+                    lowMeanErr = pLow->vignette.mean_error;
+                    highMeanErr = pHigh->vignette.mean_error;
+                    break;
+                case 1:
+                    meanErr = aPersModel[pm]->base.mean_error;
+                    lowMeanErr = pLow->base.mean_error;
+                    highMeanErr = pHigh->base.mean_error;
+                    break;
+                default: //case 2:
+                    meanErr = aPersModel[pm]->chromG.mean_error;
+                    lowMeanErr = pLow->chromG.mean_error;
+                    highMeanErr = pHigh->chromG.mean_error;
+                    break;
+                }
 
-                    // by aperture (vignette), and max out focus distance
-                    // tests showed doing this by log(aperture) is not as advisable
+                if (aperture > 0 && mode != 2) {
                     if (aPersModel[pm]->focLen == bestFocLenLow && (
-                                (aper == aperture && pLow->vignette.mean_error > meanErr)
-                                || (aper >= aperture && aper < pLow->aperture && pLow->aperture > aperture)
+                            (aper == aperture && lowMeanErr > meanErr)
+                            || (aper >= aperture && aper < pLow->aperture && pLow->aperture > aperture)
                                 || (aper <= aperture && (pLow->aperture > aperture || fabs(aperture - aper) < fabs(aperture - pLow->aperture))))) {
                         pLow = aPersModel[pm];
                     }
 
                     if (aPersModel[pm]->focLen == bestFocLenHigh && (
-                                (aper == aperture && pHigh->vignette.mean_error > meanErr)
-                                || (aper <= aperture && aper > pHigh->aperture && pHigh->aperture < aperture)
-                                || (aper >= aperture && (pHigh->aperture < aperture || fabs(aperture - aper) < fabs(aperture - pHigh->aperture))))) {
+                            (aper == aperture && highMeanErr > meanErr)
+                            || (aper <= aperture && aper > pHigh->aperture && pHigh->aperture < aperture)
+                            || (aper >= aperture && (pHigh->aperture < aperture || fabs(aperture - aper) < fabs(aperture - pHigh->aperture))))) {
+                        pHigh = aPersModel[pm];
+                    }
+                } else if (focusDist > 0 && mode != 0) {
+                    // by focus distance
+                    if (aPersModel[pm]->focLen == bestFocLenLow && (
+                            (focDist == focusDist && lowMeanErr > meanErr)
+                            || (focDist >= focusDist && focDist < pLow->focDist && pLow->focDist > focusDist)
+                            || (focDist <= focusDist && (pLow->focDist > focusDist || fabs(focusDistLog - focDistLog) < fabs(focusDistLog - (log(pLow->focDist) + euler)))))) {
+                        pLow = aPersModel[pm];
+                    }
+
+                    if (aPersModel[pm]->focLen == bestFocLenHigh && (
+                            (focDist == focusDist && highMeanErr > meanErr)
+                            || (focDist <= focusDist && focDist > pHigh->focDist && pHigh->focDist < focusDist)
+                            || (focDist >= focusDist && (pHigh->focDist < focusDist || fabs(focusDistLog - focDistLog) < fabs(focusDistLog - (log(pHigh->focDist) + euler)))))) {
                         pHigh = aPersModel[pm];
                     }
                 } else {
-                    meanErr = (mode == 1 ? aPersModel[pm]->base.mean_error : aPersModel[pm]->chromG.mean_error);
+                    // no focus distance available, just error
+                    if (aPersModel[pm]->focLen == bestFocLenLow && lowMeanErr > meanErr) {
+                        pLow = aPersModel[pm];
+                    }
 
-                    if (focusDist > 0) {
-                        // by focus distance
-                        if (aPersModel[pm]->focLen == bestFocLenLow && (
-                                    (focDist == focusDist && (mode == 1 ? pLow->base.mean_error : pLow->chromG.mean_error) > meanErr)
-                                    || (focDist >= focusDist && focDist < pLow->focDist && pLow->focDist > focusDist)
-                                    || (focDist <= focusDist && (pLow->focDist > focusDist || fabs(focusDistLog - focDistLog) < fabs(focusDistLog - (log(pLow->focDist) + euler)))))) {
-                            pLow = aPersModel[pm];
-                        }
-
-                        if (aPersModel[pm]->focLen == bestFocLenHigh && (
-                                    (focDist == focusDist && (mode == 1 ? pHigh->base.mean_error : pHigh->chromG.mean_error) > meanErr)
-                                    || (focDist <= focusDist && focDist > pHigh->focDist && pHigh->focDist < focusDist)
-                                    || (focDist >= focusDist && (pHigh->focDist < focusDist || fabs(focusDistLog - focDistLog) < fabs(focusDistLog - (log(pHigh->focDist) + euler)))))) {
-                            pHigh = aPersModel[pm];
-                        }
-                    } else {
-                        // no focus distance available, just error
-                        if (aPersModel[pm]->focLen == bestFocLenLow && (mode == 1 ? pLow->base.mean_error : pLow->chromG.mean_error) > meanErr) {
-                            pLow = aPersModel[pm];
-                        }
-
-                        if (aPersModel[pm]->focLen == bestFocLenHigh && (mode == 1 ? pHigh->base.mean_error : pHigh->chromG.mean_error) > meanErr) {
-                            pHigh = aPersModel[pm];
-                        }
+                    if (aPersModel[pm]->focLen == bestFocLenHigh && highMeanErr > meanErr) {
+                        pHigh = aPersModel[pm];
                     }
                 }
+                
             }
         }
     }
@@ -722,7 +749,7 @@ void XMLCALL LCPProfile::XmlStartHandler(void *pLCPProfile, const char *el, cons
                 nameStart++;
             }
 
-            strcpy(pProf->lastTag, nameStart);
+            strncpy(pProf->lastTag, nameStart, 255);
 
             pProf->handle_text(attr[i+1]);
             //XmlTextHandler(pLCPProfile, attr[i + 1], strlen(attr[i + 1]));
@@ -737,7 +764,7 @@ void XMLCALL LCPProfile::XmlTextHandler(void *pLCPProfile, const XML_Char *s, in
     if (!pProf->inCamProfiles || pProf->inAlternateLensID || pProf->inAlternateLensNames || *pProf->inInvalidTag) {
         return;
     }
-    
+
     for (int i = 0; i < len; ++i) {
         pProf->textbuf << s[i];
     }
@@ -746,8 +773,6 @@ void XMLCALL LCPProfile::XmlTextHandler(void *pLCPProfile, const XML_Char *s, in
 
 void LCPProfile::handle_text(std::string text)
 {
-    const char *raw = text.c_str();
-    
     // Check if it contains non-whitespaces (there are several calls to this for one tag unfortunately)
     bool onlyWhiteSpace = true;
     for (size_t i = 0; i < text.size(); ++i) {
@@ -766,6 +791,8 @@ void LCPProfile::handle_text(std::string text)
     // convert to null terminated
     char* tag = pProf->lastTag;
 
+    const char* raw = text.c_str();
+
     // Common data section
     if (!pProf->firstLIDone) {
         // Generic tags are the same for all
@@ -886,6 +913,15 @@ LCPStore* LCPStore::getInstance()
     return &instance_;
 }
 
+
+LCPStore::~LCPStore()
+{
+    for (auto &p : profileCache) {
+        delete p.second;
+    }
+}
+
+
 LCPProfile* LCPStore::getProfile (Glib::ustring filename)
 {
     if (filename.length() == 0 || !isValidLCPFileName(filename)) {
