@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -20,27 +20,33 @@
 #include "stdimagesource.h"
 #include "rawimagesource.h"
 
-namespace rtengine {
+namespace rtengine
+{
 
-InitialImage* InitialImage::load (const Glib::ustring& fname, bool isRaw, int* errorCode, ProgressListener* pl) {
+InitialImage* InitialImage::load (const Glib::ustring& fname, bool isRaw, int* errorCode, ProgressListener* pl)
+{
 
     ImageSource* isrc;
 
-    if (!isRaw) 
+    if (!isRaw) {
         isrc = new StdImageSource ();
-    else 
+    } else {
         isrc = new RawImageSource ();
+    }
 
     isrc->setProgressListener (pl);
 
-    if(isRaw && pl == NULL)
+    if(isRaw && pl == nullptr) {
         *errorCode = isrc->load (fname, true);
-    else
+    } else {
         *errorCode = isrc->load (fname);
-    if (*errorCode) {
-        delete isrc;    
-        return NULL;
     }
+
+    if (*errorCode) {
+        delete isrc;
+        return nullptr;
+    }
+
     return isrc;
 }
 }
