@@ -73,7 +73,7 @@ enum ProcEvent {
     EvLDNRadius = 43, // obsolete
     EvLDNEdgeTolerance = 44, // obsolete
     EvCDNEnabled = 45, // obsolete
-    EvBlendCMSMatrix = 46,
+    EvBlendCMSMatrix = 46, // obsolete
     EvDCPToneCurve = 47,
     EvDCPIlluminant = 48,
     EvSHEnabled = 49,
@@ -451,7 +451,7 @@ enum ProcEvent {
     EvLgam = 421,
     EvLslope = 422,
     EvLhighl = 423,
-    EvLbaselog = 424,
+//    EvLbaselog = 424,   -- can be reused --
     EvRetinexlhcurve = 425,
     EvOIntent = 426,
     EvMonitorTransform = 427,
