@@ -312,7 +312,6 @@ public:
     double  gam;
     double  slope;
     int     neigh;
-    int     gain;
     int     offs;
     int     highlights;
     int     htonalwidth;
@@ -328,7 +327,6 @@ public:
     int     vart;
     int     limd;
     int     highl;
-    double     baselog;
     int     skal;
     bool    medianmap;
     RetinexParams ();
@@ -467,7 +465,7 @@ public:
     int            deconviter;
     int            deconvdamping;
 
-    SharpeningParams() : threshold(20, 80, 2000, 1200, false) {};
+    SharpeningParams();
 };
 class SharpenEdgeParams
 {
@@ -502,7 +500,7 @@ public:
     bool           pastsattog;
     std::vector<double> skintonescurve;
 
-    VibranceParams() : psthreshold(0, 75,  false) {};
+    VibranceParams();
 };
 
 /**
@@ -690,7 +688,6 @@ public:
     bool    enabled;
     bool    enhance;
     bool    median;
-    bool    autochroma;
 
     bool    perform;
     double  luma;
@@ -983,7 +980,6 @@ public:
     bool          applyLookTable;
     bool          applyBaselineExposureOffset;
     bool          applyHueSatMap;
-    bool          blendCMSMatrix; // setting no longer used
     int dcpIlluminant;
     Glib::ustring working;
     Glib::ustring output;
@@ -1284,7 +1280,6 @@ public:
     int ff_clipControl;
 
     bool ca_autocorrect;
-    double caautostrength;
     double cared;
     double cablue;
 
