@@ -310,6 +310,27 @@ public :
 
 };
 
+class AutoWBListener
+{
+public :
+    virtual ~AutoWBListener() = default;
+    virtual void WBChanged(double temp, double green) = 0;
+};
+
+class FrameCountListener
+{
+public :
+    virtual ~FrameCountListener() = default;
+    virtual void FrameCountChanged(int n, int frameNum) = 0;
+};
+
+class ImageTypeListener
+{
+public :
+    virtual ~ImageTypeListener() = default;
+    virtual void imageTypeChanged(bool isRaw, bool isBayer, bool isXtrans) = 0;
+};
+
 class WaveletListener
 {
 public :
@@ -396,7 +417,7 @@ public:
       * @return a pointer to the Crop object that handles the image data trough its own pipeline */
     virtual DetailedCrop* createCrop  (::EditDataProvider *editDataProvider, bool isDetailWindow) = 0;
 
-    virtual bool        getAutoWB   (double& temp, double& green, double equal) = 0;
+    virtual bool        getAutoWB   (double& temp, double& green, double equal, double tempBias) = 0;
     virtual void        getCamWB    (double& temp, double& green) = 0;
     virtual void        getSpotWB  (int x, int y, int rectSize, double& temp, double& green) = 0;
     virtual void        getAutoCrop (double ratio, int &x, int &y, int &w, int &h) = 0;
@@ -410,11 +431,14 @@ public:
     virtual void        setHistogramListener    (HistogramListener *l) = 0;
     virtual void        setPreviewImageListener (PreviewImageListener* l) = 0;
     virtual void        setAutoCamListener      (AutoCamListener* l) = 0;
+    virtual void        setFrameCountListener   (FrameCountListener* l) = 0;
     virtual void        setAutoBWListener       (AutoBWListener* l) = 0;
+    virtual void        setAutoWBListener       (AutoWBListener* l) = 0;
     virtual void        setAutoColorTonListener (AutoColorTonListener* l) = 0;
     virtual void        setAutoChromaListener   (AutoChromaListener* l) = 0;
     virtual void        setRetinexListener      (RetinexListener* l) = 0;
     virtual void        setWaveletListener      (WaveletListener* l) = 0;
+    virtual void        setImageTypeListener    (ImageTypeListener* l) = 0;
 
     virtual void        setMonitorProfile       (const Glib::ustring& monitorProfile, RenderingIntent intent) = 0;
     virtual void        getMonitorProfile       (Glib::ustring& monitorProfile, RenderingIntent& intent) const = 0;
@@ -435,24 +459,19 @@ public:
   * @brief Initializes the RT engine
   * @param s is a struct of basic settings
   * @param baseDir base directory of RT's installation dir
-  * @param userSettingsDir RT's base directory in the user's settings dir */
-int init (const Settings* s, Glib::ustring baseDir, Glib::ustring userSettingsDir);
+  * @param userSettingsDir RT's base directory in the user's settings dir
+  * @param loadAll if false, don't load the various dependencies (profiles, HALDClut files, ...), they'll be loaded from disk each time they'll be used (launching time improvement) */
+int init (const Settings* s, Glib::ustring baseDir, Glib::ustring userSettingsDir, bool loadAll = true);
 
 /** Cleanup the RT engine (static variables) */
 void cleanup ();
 
-/** Returns the available working profile names
-  * @return a vector of the available working profile names */
-std::vector<Glib::ustring> getWorkingProfiles ();
-/** Returns the available output gammas
-  * @return a vector of the available gamma names */
-std::vector<Glib::ustring> getGamma ();
-
 /** This class  holds all the necessary informations to accomplish the full processing of the image */
 class ProcessingJob
 {
 
 public:
+    virtual ~ProcessingJob() {}
 
     /** Creates a processing job from a file name. This function always succeeds. It only stores the data into the ProcessingJob class, it does not load
        * the image thus it returns immediately.
@@ -460,7 +479,7 @@ public:
        * @param isRaw shall be true if it is a raw file
        * @param pparams is a struct containing the processing parameters
        * @return an object containing the data above. It can be passed to the functions that do the actual image processing. */
-    static ProcessingJob* create (const Glib::ustring& fname, bool isRaw, const procparams::ProcParams& pparams);
+    static ProcessingJob* create (const Glib::ustring& fname, bool isRaw, const procparams::ProcParams& pparams, bool fast=false);
 
     /** Creates a processing job from a file name. This function always succeeds. It only stores the data into the ProcessingJob class, it does not load
        * the image thus it returns immediately. This function increases the reference count of the initialImage. If you decide not the process the image you
@@ -469,12 +488,14 @@ public:
        * @param initialImage is a loaded and pre-processed initial image
        * @param pparams is a struct containing the processing parameters
        * @return an object containing the data above. It can be passed to the functions that do the actual image processing. */
-    static ProcessingJob* create (InitialImage* initialImage, const procparams::ProcParams& pparams);
+    static ProcessingJob* create (InitialImage* initialImage, const procparams::ProcParams& pparams, bool fast=false);
 
     /** Cancels and destroys a processing job. The reference count of the corresponding initialImage (if any) is decreased. After the call of this function the ProcessingJob instance
       * gets invalid, you must not use it any more. Dont call this function while the job is being processed.
       * @param job is the job to destroy */
     static void destroy (ProcessingJob* job);
+
+    virtual bool fastPipeline() const = 0;
 };
 
 /** This function performs all the image processinf steps corresponding to the given ProcessingJob. It returns when it is ready, so it can be slow.
