@@ -1065,7 +1065,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         int origFH;
         double tscale = 0.0;
         getDimensions(origFW, origFH, tscale);
-        ipf.transform (baseImg, trImg, 0, 0, 0, 0, fw, fh, origFW * tscale + 0.5, origFH * tscale + 0.5, focalLen, focalLen35mm, focusDist, 0, true); // Raw rotate degree not detectable here
+        ipf.transform (baseImg, trImg, 0, 0, 0, 0, fw, fh, origFW * tscale + 0.5, origFH * tscale + 0.5, focalLen, focalLen35mm, focusDist, fnumber, 0, true); // Raw rotate degree not detectable here
         delete baseImg;
         baseImg = trImg;
     }
@@ -1296,7 +1296,7 @@ IImage8* Thumbnail::processImage (const procparams::ProcParams& params, int rhei
         CAMMean = NAN;
         CAMBrightCurveJ.dirty = true;
         CAMBrightCurveQ.dirty = true;
-        ipf.ciecam_02float (cieView, adap, begh, endh, 1, 2, labView, &params, customColCurve1, customColCurve2, customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, 6, execsharp, d, sk, rtt);
+        ipf.ciecam_02float (cieView, adap, begh, endh, 1, 2, labView, &params, customColCurve1, customColCurve2, customColCurve3, dummy, dummy, CAMBrightCurveJ, CAMBrightCurveQ, CAMMean, 5, sk, execsharp, d, rtt);
         delete cieView;
     }
 
@@ -1988,21 +1988,25 @@ bool Thumbnail::writeData  (const Glib::ustring& fname)
 bool Thumbnail::readEmbProfile  (const Glib::ustring& fname)
 {
 
-    FILE* f = g_fopen (fname.c_str (), "rb");
+    embProfileData = nullptr;
+    embProfile = nullptr;
+    embProfileLength = 0;
 
-    if (!f) {
-        embProfileData = nullptr;
-        embProfile = nullptr;
-        embProfileLength = 0;
-    } else {
-        fseek (f, 0, SEEK_END);
-        embProfileLength = ftell (f);
-        fseek (f, 0, SEEK_SET);
-        embProfileData = new unsigned char[embProfileLength];
-        fread (embProfileData, 1, embProfileLength, f);
+    FILE* f = g_fopen (fname.c_str (), "rb");
+    if (f) {
+        if(!fseek (f, 0, SEEK_END)) {
+            int profileLength = ftell (f);
+            if(profileLength > 0) {
+                embProfileLength = profileLength;
+                if(!fseek (f, 0, SEEK_SET)) {
+                    embProfileData = new unsigned char[embProfileLength];
+                    fread (embProfileData, 1, embProfileLength, f);
+                    embProfile = cmsOpenProfileFromMem (embProfileData, embProfileLength);
+                }
+            }
+        }
         fclose (f);
-        embProfile = cmsOpenProfileFromMem (embProfileData, embProfileLength);
-        return true;
+        return embProfile != nullptr;
     }
 
     return false;
