@@ -171,7 +171,7 @@ void BatchToolPanelCoordinator::initSession ()
             blackwhite->setAdjusterBehavior (false, false);
             colortoning->setAdjusterBehavior (false, false, false, false, false);
             filmSimulation->setAdjusterBehavior(false);
-            retinex->setAdjusterBehavior (false, false, false, false, false, false, false, false);
+            retinex->setAdjusterBehavior (false, false, false, false, false, false, false);
 
             shadowshighlights->setAdjusterBehavior (false, false, false);
             dirpyrequalizer->setAdjusterBehavior (false, false, false);
@@ -208,7 +208,7 @@ void BatchToolPanelCoordinator::initSession ()
 //          colortoning->setAdjusterBehavior (options.baBehav[ADDSET_COLORTONING_SPLIT], options.baBehav[ADDSET_COLORTONING_SATTHRESHOLD], options.baBehav[ADDSET_COLORTONING_SATOPACITY], options.baBehav[ADDSET_COLORTONING_STRPROTECT], options.baBehav[ADDSET_COLORTONING_BALANCE]);
             colortoning->setAdjusterBehavior (options.baBehav[ADDSET_COLORTONING_SPLIT], options.baBehav[ADDSET_COLORTONING_SATTHRESHOLD], options.baBehav[ADDSET_COLORTONING_SATOPACITY], options.baBehav[ADDSET_COLORTONING_STRENGTH], options.baBehav[ADDSET_COLORTONING_BALANCE]);
             filmSimulation->setAdjusterBehavior(options.baBehav[ADDSET_FILMSIMULATION_STRENGTH]);
-            retinex->setAdjusterBehavior (options.baBehav[ADDSET_RETI_STR], options.baBehav[ADDSET_RETI_NEIGH], options.baBehav[ADDSET_RETI_LIMD], options.baBehav[ADDSET_RETI_GAIN], options.baBehav[ADDSET_RETI_OFFS], options.baBehav[ADDSET_RETI_VART], options.baBehav[ADDSET_RETI_GAM], options.baBehav[ADDSET_RETI_SLO]);
+            retinex->setAdjusterBehavior (options.baBehav[ADDSET_RETI_STR], options.baBehav[ADDSET_RETI_NEIGH], options.baBehav[ADDSET_RETI_LIMD], options.baBehav[ADDSET_RETI_OFFS], options.baBehav[ADDSET_RETI_VART], options.baBehav[ADDSET_RETI_GAM], options.baBehav[ADDSET_RETI_SLO]);
 
             chmixer->setAdjusterBehavior (options.baBehav[ADDSET_CHMIXER] );
             blackwhite->setAdjusterBehavior (options.baBehav[ADDSET_BLACKWHITE_HUES], options.baBehav[ADDSET_BLACKWHITE_GAMMA]);
@@ -602,10 +602,6 @@ void BatchToolPanelCoordinator::initSession ()
                 pparams.retinex.limd = 0;
             }
 
-            if (options.baBehav[ADDSET_RETI_GAIN]) {
-                pparams.retinex.gain = 0;
-            }
-
             if (options.baBehav[ADDSET_RETI_OFFS]) {
                 pparams.retinex.offs = 0;
             }
