@@ -54,7 +54,7 @@ int notifyListenerUI (void* data)
 
 }
 
-Crop::Crop (): FoldableToolPanel(this, "crop", M("TP_CROP_LABEL"), false, true)
+Crop::Crop (): FoldableToolPanel(this, "crop", M("TP_CROP_LABEL"), false, true), opt(0), wDirty(true), hDirty(true), xDirty(true), yDirty(true), lastFixRatio(true)
 {
 
     clistener = nullptr;
@@ -1219,10 +1219,6 @@ void Crop::cropResized (int &x, int &y, int& x2, int& y2)
         W = maxw;
     }
 
-    if (H > maxh) {
-        H = maxh;
-    }
-
     if (fixr->get_active()) {
         double r = getRatio ();
 
