@@ -18,9 +18,11 @@
  */
 #include "dirbrowser.h"
 
+#include <iostream>
 #include <cstring>
 
-#ifdef WIN32
+#ifdef _WIN32_WINNT
+#undef _WIN32_WINNT
 #define _WIN32_WINNT 0x0600
 #include <windows.h>
 #endif
@@ -99,6 +101,11 @@ DirBrowser::DirBrowser () : dirTreeModel(),
     scrolledwindow4->show ();
 }
 
+DirBrowser::~DirBrowser()
+{
+    idle_register.destroy();
+}
+
 void DirBrowser::fillDirTree ()
 {
 
@@ -226,16 +233,16 @@ int updateVolumesUI (void* br)
     (static_cast<DirBrowser*>(br))->updateVolumes ();
     return 1;
 }
-int updateDirTreeUI (void* br)
-{
-    (static_cast<DirBrowser*>(br))->updateDirTreeRoot ();
-    return 0;
-}
 
 void DirBrowser::winDirChanged ()
 {
+    const auto func = [](gpointer data) -> gboolean {
+        static_cast<DirBrowser*>(data)->updateDirTreeRoot();
 
-    g_idle_add (updateDirTreeUI, this);
+        return FALSE;
+    };
+
+    idle_register.add(func, this);
 }
 #endif
 
@@ -347,7 +354,7 @@ void DirBrowser::updateDir (const Gtk::TreeModel::iterator& iter)
     auto dir = Gio::File::create_for_path (iter->get_value (dtColumns.dirname));
     auto subDirs = listSubDirs (dir, options.fbShowHidden);
 
-    for (int i = 0; i < subDirs.size(); i++) {
+    for (size_t i = 0; i < subDirs.size(); i++) {
         bool found = false;
 
         for (Gtk::TreeModel::iterator it = iter->children().begin(); it != iter->children().end() && !found ; ++it) {
