@@ -53,12 +53,6 @@ public:
     }
 };
 
-struct FileBrowserIdleHelper {
-    FileBrowser* fbrowser;
-    bool destroyed;
-    int pending;
-};
-
 /*
  * Class handling actions common to all thumbnails of the file browser
  */
@@ -71,6 +65,7 @@ private:
     typedef sigc::signal<void> type_trash_changed;
 
     IdleRegister idle_register;
+    unsigned int session_id_;
 
 protected:
     Gtk::MenuItem* rank[6];
@@ -129,7 +124,6 @@ protected:
     FileBrowserListener* tbl;
     BrowserFilter filter;
     int numFiltered;
-    FileBrowserIdleHelper* fbih;
 
     void toTrashRequested   (std::vector<FileBrowserEntry*> tbe);
     void fromTrashRequested (std::vector<FileBrowserEntry*> tbe);
@@ -152,6 +146,8 @@ public:
     FileBrowserEntry*  delEntry (const Glib::ustring& fname);    // return the entry if found here return NULL otherwise
     void close ();
 
+    unsigned int session_id() const { return session_id_; }
+
     void setBatchPParamsChangeListener (BatchPParamsChangeListener* l)
     {
         bppcl = l;
