@@ -59,7 +59,7 @@ Glib::ustring argv0;
 Glib::ustring creditsPath;
 Glib::ustring licensePath;
 Glib::ustring argv1;
-bool simpleEditor;
+//bool simpleEditor;
 //Glib::Threads::Thread* mainThread;
 
 namespace
@@ -115,12 +115,12 @@ int main(int argc, char **argv)
     // get the path where the rawtherapee executable is stored
 #ifdef WIN32
     WCHAR exnameU[512] = {0};
-    GetModuleFileNameW (NULL, exnameU, 512);
-    WideCharToMultiByte(CP_UTF8, 0, exnameU, -1, exname, 512, 0, 0 );
+    GetModuleFileNameW (NULL, exnameU, 511);
+    WideCharToMultiByte(CP_UTF8, 0, exnameU, -1, exname, 511, 0, 0 );
 #else
 
-    if (readlink("/proc/self/exe", exname, 512) < 0) {
-        strncpy(exname, argv[0], 512);
+    if (readlink("/proc/self/exe", exname, 511) < 0) {
+        strncpy(exname, argv[0], 511);
     }
 
 #endif
@@ -294,6 +294,7 @@ int processLineParams( int argc, char **argv )
     Glib::ustring outputPath = "";
     std::vector<rtengine::procparams::PartialProfile*> processingParams;
     bool outputDirectory = false;
+    bool leaveUntouched = false;
     bool overwriteFiles = false;
     bool sideProcParams = false;
     bool copyParamsFile = false;
@@ -324,7 +325,11 @@ int processLineParams( int argc, char **argv )
 #if ECLIPSE_ARGS
                     outputPath = outputPath.substr(1, outputPath.length()-2);
 #endif
-                    if( Glib::file_test (outputPath, Glib::FILE_TEST_IS_DIR)) {
+                    if(outputPath.substr(0,9) == "/dev/null") {
+                        outputPath.assign("/dev/null");  // removing any useless chars or filename
+                        outputDirectory = false;
+                        leaveUntouched = true;
+                    } else if(Glib::file_test (outputPath, Glib::FILE_TEST_IS_DIR)) {
                         outputDirectory = true;
                     }
                 }
@@ -425,7 +430,7 @@ int processLineParams( int argc, char **argv )
 
             case 't':
                 outputType = "tif";
-                compression = ((currParam.at(2) != 'z') ? 0 : 1);
+                compression = ((currParam.size() < 3 || currParam.at(2) != 'z') ? 0 : 1);
                 break;
 
             case 'n':
@@ -476,14 +481,14 @@ int processLineParams( int argc, char **argv )
 
                         try {
 
-                            auto enumerator = dir->enumerate_children ();
+                            auto enumerator = dir->enumerate_children("standard::name,standard::type");
 
-                            while (auto file = enumerator->next_file ()) {
+                            while (auto file = enumerator->next_file()) {
 
-                                const auto fileName = Glib::build_filename (argument, file->get_name ());
-                                bool isDir = Glib::file_test (fileName, Glib::FILE_TEST_IS_DIR);
-                                bool notAll = allExtensions && !options.is_parse_extention (fileName);
-                                bool notRetained = !allExtensions && !options.has_retained_extention (fileName);
+                                const auto fileName = Glib::build_filename(argument, file->get_name());
+                                bool isDir = file->get_file_type() == Gio::FILE_TYPE_DIRECTORY;
+                                bool notAll = allExtensions && !options.is_parse_extention(fileName);
+                                bool notRetained = !allExtensions && !options.has_retained_extention(fileName);
 
                                 if (isDir || notAll || notRetained) {
                                     if (isDir) {
@@ -696,9 +701,13 @@ int processLineParams( int argc, char **argv )
             Glib::ustring::size_type ext = s.find_last_of('.');
             outputFile = Glib::build_filename(outputPath, s.substr(0, ext) + "." + outputType);
         } else {
-            Glib::ustring s = outputPath;
-            Glib::ustring::size_type ext = s.find_last_of('.');
-            outputFile =  s.substr(0, ext) + "." + outputType;
+            if (leaveUntouched) {
+                outputFile = outputPath;
+            } else {
+                Glib::ustring s = outputPath;
+                Glib::ustring::size_type ext = s.find_last_of('.');
+                outputFile = s.substr(0, ext) + "." + outputType;
+            }
         }
 
         if( inputFile == outputFile) {
