@@ -132,11 +132,19 @@ public:
     bool browserDirPanelOpened;
     bool editorFilmStripOpened;
     int historyPanelWidth;
-    int windowWidth;
-    int windowHeight;
     int windowX;
     int windowY;
+    int windowWidth;
+    int windowHeight;
     bool windowMaximized;
+    int windowMonitor;
+    int meowMonitor;
+    bool meowFullScreen;
+    bool meowMaximized;
+    int meowWidth;
+    int meowHeight;
+    int meowX;
+    int meowY;
     int detailWindowWidth;
     int detailWindowHeight;
     int dirBrowserWidth;
@@ -358,6 +366,8 @@ extern Options options;
 extern Glib::ustring argv0;
 extern Glib::ustring argv1;
 extern bool simpleEditor;
+extern bool gimpPlugin;
+extern bool remote;
 extern Glib::ustring versionString;
 extern Glib::ustring paramFileExtension;
 
