@@ -26,9 +26,9 @@
 #include "guiutils.h"
 
 PopUpCommon::PopUpCommon (Gtk::Button* thisButton, const Glib::ustring& label)
-    : selected (-1) // -1 means that the button is invalid
+    : buttonImage (nullptr)
     , menu (nullptr)
-    , buttonImage (nullptr)
+    , selected (-1) // -1 means that the button is invalid
 {
     button = thisButton;
     hasMenu = false;
@@ -107,8 +107,8 @@ void PopUpCommon::entrySelected (int i)
 
 void PopUpCommon::setItemSensitivity (int index, bool isSensitive) {
     const auto items = menu->get_children ();
-    if (index < items.size ()) {
-        items[index]->set_sensitive (isSensitive);
+    if (size_t(index) < items.size ()) {
+        items[size_t(index)]->set_sensitive (isSensitive);
     }
 }
 
