@@ -7,7 +7,7 @@
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  RawTherapee is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -23,33 +23,33 @@
 #include "adjuster.h"
 #include "toolpanel.h"
 
-class ShadowsHighlights : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel {
+class ShadowsHighlights : public ToolParamBlock, public AdjusterListener, public FoldableToolPanel
+{
 
-  protected:
+protected:
     Adjuster* highlights;
     Adjuster* h_tonalwidth;
     Adjuster* shadows;
     Adjuster* s_tonalwidth;
     Adjuster* lcontrast;
     Adjuster* radius;
-    Gtk::CheckButton* enabled;
     Gtk::CheckButton* hq;
-    bool                lastEnabled, lastHQ;
-    sigc::connection    enaConn, hqConn;
+    bool lastHQ;
+    sigc::connection hqConn;
 
-  public:
+public:
 
     ShadowsHighlights ();
 
-    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited=NULL); 
-    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited=NULL);
-    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited=NULL);
+    void read           (const rtengine::procparams::ProcParams* pp, const ParamsEdited* pedited = nullptr);
+    void write          (rtengine::procparams::ProcParams* pp, ParamsEdited* pedited = nullptr);
+    void setDefaults    (const rtengine::procparams::ProcParams* defParams, const ParamsEdited* pedited = nullptr);
     void setBatchMode   (bool batchMode);
 
     void adjusterChanged (Adjuster* a, double newval);
-    void enabledChanged ();
-    void hqChanged ();
-    
+    void enabledChanged  ();
+    void hqChanged       ();
+
     void setAdjusterBehavior (bool hadd, bool sadd, bool lcadd);
     void trimValues          (rtengine::procparams::ProcParams* pp);
 };
