@@ -49,7 +49,6 @@ class Thumbnail
 
     rtengine::procparams::ProcParams      pparams;
     bool            pparamsValid;
-    bool            pparamsSet;
     bool            needsReProcessing;
     bool            imageLoading;
 
@@ -87,7 +86,7 @@ public:
     const rtengine::procparams::ProcParams& getProcParamsU ();  // Unprotected version
 
     // Use this to create params on demand for update ; if flaggingMode=true, the procparams is created for a file being flagged (inTrash, rank, colorLabel)
-    rtengine::procparams::ProcParams* createProcParamsForUpdate (bool returnParams, bool forceCPB, bool flaggingMode = false);
+    rtengine::procparams::ProcParams* createProcParamsForUpdate (bool returnParams, bool force, bool flaggingMode = false);
 
     void              setProcParams (const rtengine::procparams::ProcParams& pp, ParamsEdited* pe = nullptr, int whoChangedIt = -1, bool updateCacheNow = true);
     void              clearProcParams (int whoClearedIt = -1);
@@ -125,7 +124,7 @@ public:
             temp = green = -1.0;
         }
     }
-    void                  getAutoWB (double& temp, double& green, double equal);
+    void                  getAutoWB (double& temp, double& green, double equal, double tempBias);
     void                  getSpotWB (int x, int y, int rect, double& temp, double& green)
     {
         if (tpp) {
